@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: __init__.py 11314 2018-12-14 05:31:25Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-07-16 17:31:00 +0800 (Mon, 16 Jul 2018) $
-# $Revision: 11172 $
+# $Author: Kevin $ (last)
+# $Date: 2018-12-14 14:31:25 +0900 (週五, 14 十二月 2018) $
+# $Revision: 11314 $
 
 import logging
 
@@ -39,6 +39,22 @@ def attachSettings(settingsLocals, backends, preferred, config):
                         "'force': True in cloud logging settings "
                         "if you insist.")        
             return
+        else: # force = True
+            loggingSettings = settingsLocals.get("LOGGING", None)
+            if loggingSettings:
+                # Avoid get_current_site() recursive bug:
+                # https://stackoverflow.com/questions/7768027/
+                # turn-off-sql-logging-while-keeping-settings-debug
+                loggersSettings = loggingSettings.get('loggers', None)
+                if (loggersSettings and
+                    'django.db.backends' not in loggersSettings):
+                    loggersSettings.update({
+                        'django.db.backends': {
+                            'handlers': None,  # Quiet by default!
+                            'propagate': False,
+                            'level': 'DEBUG',
+                        },
+                    })
 
     hostInfo = tryGet('getSentryInfo', backends, preferred, config)
     if not hostInfo:
@@ -64,10 +80,10 @@ def attachSettings(settingsLocals, backends, preferred, config):
         'RAVEN_CONFIG': {
             'dsn': hostInfo.info['SENTRY_DSN'],
         },
-        'MIDDLEWARE_CLASSES': settingsLocals.get('MIDDLEWARE_CLASSES', ()) + (
+        'MIDDLEWARE_CLASSES': settingsLocals.get('MIDDLEWARE_CLASSES', ()) + [
             ('raven.contrib.django.raven_compat.middleware.'
              'SentryResponseErrorIdMiddleware'),
-        ),
+        ],
     })
 
     from raven.contrib.django.handlers import SentryHandler as CloudHandler
