@@ -814,7 +814,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
             "ReceiverCellPhone": mapData['receiverPhone'], 
             
             # 隨時接訂單資訊的 URL
-            "ServerReplyURL": reverse("ecpayLogisticReply"), 
+            "ServerReplyURL": backUrl[:-1] + reverse("ecpayLogisticReply"), 
             "ClientReplyURL": returnUrl,               
         }
         
