@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11295 2018-12-05 13:49:49Z Lavender $
+# $Id: views.py 11310 2018-12-13 07:40:43Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-12-05 22:49:49 +0900 (週三, 05 十二月 2018) $
-# $Revision: 11295 $ 
+# $Date: 2018-12-13 16:40:43 +0900 (週四, 13 十二月 2018) $
+# $Revision: 11310 $ 
 
 import json
 import logging
@@ -953,12 +953,27 @@ class ECPayServerReplyView(generic.View):
 
             if self.rtnMerchantTradeNo:
                 logisticTrade = ECPayLogisticTrade.objects.filter(
-                    tradeNo=self.tradeNo).update(
-                        rtnCode=self.rtnCode,
-                        rtnMsg=self.rtnMsg,
-                        updateStatusDate=self.updateStatusDate.replace(
-                            '/', '-'),
+                    tradeNo=self.tradeNo).order_by('-id').first()
+
+                newLogisticTrade = ECPayLogisticTrade.objects.create(
+                    tradeNo=self.tradeNo,
+                    tradeAmt=int(self.tradeAmt),
+                    merchantId=self.merchantID,
+                    merchantTradeNo=self.merchantTradeNo,
+                    rtnCode=self.rtnCode,
+                    rtnMsg=self.rtnMsg,
+                    tradeDate=logisticTrade.tradeDate,
+                    updateStatusDate=self.updateStatusDate.replace('/', '-'),
+                    receiverName=self.receiverName,
+                    receiverCellPhone=self.receiverCellPhone,
+                    receiverEmail=self.receiverEmail,
+                    logisticsType=self.logisticsType,
+                    logisticsSubType=self.logisticsSubType,
+                    paymentNo=self.paymentNo,
+                    validationNo=self.validationNo,
+                    rtnMerchantTradeNo=self.rtnMerchantTradeNo,
                 )
+                
                 return HttpResponse("1|OK")
             else:
                 index = self.merchantTradeNo.find('BASKETID')
