@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: models.py 11314 2018-12-14 05:31:25Z Kevin $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-07-16 17:31:00 +0800 (Mon, 16 Jul 2018) $
-# $Revision: 11172 $
+# $Author: Kevin $ (last)
+# $Date: 2018-12-14 14:31:25 +0900 (週五, 14 十二月 2018) $
+# $Revision: 11314 $
 
 import os
 import hashlib
@@ -26,7 +26,7 @@ from django.db.models import Max
 from mptt.models import MPTTModel, TreeForeignKey
 
 from Iuno.template_editor import (
-    BACKUP_DIR_NAME, BACKUP_FILE_DIR, STATIC_DIR, TEMPLATE_DIR)
+    BACKUP_DIR_NAME, BACKUP_FILE_DIR, STATIC_DIR, TEMPLATE_DIR, toBytes)
 
 FOLDER = 1
 FILE = 2
@@ -77,7 +77,7 @@ class VersionControlMixin(object):
     def getVersion(self, versionNumber=None):
         if self.type == FILE:
             path = self.path
-            dirName = hashlib.md5(path).hexdigest()
+            dirName = hashlib.md5(toBytes(path)).hexdigest()
 
             if Version.objects.filter(dirName=dirName).exists():
                 if versionNumber:
